@@ -1,5 +1,6 @@
 from __future__ import unicode_literals, print_function, absolute_import, division, generators, nested_scopes
 from datetime import datetime
+import logging
 
 import six
 from six.moves import map
@@ -9,6 +10,8 @@ from jsonpath_rw.parser import parse as parse_jsonpath
 
 from commcare_export.repeatable_iterator import RepeatableIterator
 
+logger = logging.getLogger(__name__)
+
 class MiniLinq(object):
     """
     The abstract base class for MiniLinqs, and also the factory/registry
@@ -371,20 +374,27 @@ class Emit(MiniLinq):
         self.headings = headings
         self.source = source
 
-    def coerce_cell(self, cell):
+    def coerce_cell_blithely(self, cell):
         if isinstance(cell, jsonpath.DatumInContext):
             cell = cell.value
         
         if isinstance(cell, six.string_types):
             return cell
         elif isinstance(cell, int):
-            return cell
+            return str(cell)
         elif isinstance(cell, datetime):
             return cell 
 
         # In all other cases, coerce to a list and join with ',' for now
-        return ','.join([str(self.coerce_cell(item)) for item in list(cell)])
-        
+        return ','.join([self.coerce_cell(item) for item in list(cell)])
+
+    def coerce_cell(self, cell):
+        try:
+            return self.coerce_cell_blithely(cell)
+        except Exception:
+            logger.error('Error converting value to exportable form: %r' % cell)
+            return ''
+            
     def coerce_row(self, row):
         return [self.coerce_cell(cell) for cell in row]
 
